@@ -1,3 +1,6 @@
+use v5.10;
+use utf8;
+
 package Business::US::USPS::WebTools;
 use strict;
 no warnings 'uninitialized';
@@ -7,7 +10,7 @@ use Carp qw(croak);
 use subs qw();
 use vars qw($VERSION);
 
-$VERSION = '1.12';
+$VERSION = '1.121';
 
 =encoding utf8
 
@@ -59,8 +62,7 @@ is false or not present, the object uses the live server details.
 
 =cut
 
-sub new
-	{
+sub new {
 	my( $class, $args ) = @_;
 
 	my $user_id = $args->{UserID} || $ENV{USPS_WEBTOOLS_USERID} ||
@@ -109,8 +111,7 @@ sub password { $_[0]->{Password} }
 sub url      { $_[0]->{url} || $_[0]->_make_url }
 sub response { $_[0]->{response} }
 
-sub _api_host
-	{
+sub _api_host {
 	my $self = shift;
 
 	if( $self->_testing ) { $TestServer }
@@ -125,8 +126,7 @@ sub _api_path {
 		"/ShippingAPITest.dll"
 		}
 
-sub _make_query_string
-	{
+sub _make_query_string {
 	require URI;
 
 	my( $self, $hash ) = @_;
@@ -142,16 +142,14 @@ sub _make_query_string
 	$uri->query; # this should work, but doesn't
 	}
 
-sub _make_url
-	{
+sub _make_url {
 	my( $self, $hash ) = @_;
 
 	$self->{url} = qq|http://| . $self->_api_host . $self->_api_path .
 		"?" . $self->_make_query_string( $hash );
 	}
 
-sub _make_request
-	{
+sub _make_request {
 	my( $self, $url ) = @_;
 	require LWP::Simple;
 
@@ -184,8 +182,7 @@ object:
 
 =cut
 
-sub is_error
-	{
+sub is_error {
 	my $self = shift;
 
 	return 0 unless $self->response =~ "<Error>";
@@ -215,13 +212,9 @@ http://www.usps.com/webtools/htm/Address-Information.htm
 
 =head1 SOURCE AVAILABILITY
 
-This source is part of a SourceForge project which always has the
-latest sources in CVS, as well as all of the previous releases.
+This source is in GitHub:
 
-	http://sourceforge.net/projects/brian-d-foy/
-
-If, for some reason, I disappear from the world, one of the other
-members of the project can shepherd this module appropriately.
+	https://github.com/briandfoy/business-us-usps-webtools
 
 =head1 AUTHOR
 
@@ -229,7 +222,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2006-2015, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2006-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
