@@ -1,3 +1,6 @@
+use v5.10;
+use utf8;
+
 package Business::US::USPS::WebTools::AddressStandardization;
 use strict;
 no warnings 'uninitialized';
@@ -7,7 +10,7 @@ use parent qw(Business::US::USPS::WebTools);
 use subs qw();
 use vars qw($VERSION);
 
-$VERSION = '1.12';
+$VERSION = '1.121';
 
 =encoding utf8
 
@@ -93,8 +96,7 @@ details on error information.
 
 =cut
 
-sub verify_address
-	{
+sub verify_address {
 	my( $self, %hash ) = @_;
 
 	$self->_make_url( \%hash );
@@ -107,8 +109,7 @@ sub verify_address
 
 sub _api_name { "Verify" }
 
-sub _make_query_xml
-	{
+sub _make_query_xml {
 	my( $self, $hash ) = @_;
 
 	my $user = $self->userid;
@@ -120,8 +121,7 @@ sub _make_query_xml
 		qq|<ReturnCarrierRoute>true</ReturnCarrierRoute>|  .
 		qq|<Address ID="0">|;
 
-	foreach my $field ( $self->_fields )
-		{
+	foreach my $field ( $self->_fields ) {
 		$xml .= "<$field>$$hash{$field}</$field>";
 		}
 
@@ -130,14 +130,12 @@ sub _make_query_xml
 	return $xml;
 	}
 
-sub _parse_response
-	{
+sub _parse_response {
 	my( $self ) = @_;
 	#require 'Hash::AsObject';
 
 	my %hash = ();
-	foreach my $field ( $self->_response )
-		{
+	foreach my $field ( $self->_response ) {
 		my( $value ) = $self->response =~ m|<$field>(.*?)</$field>|g;
 
 		$hash{$field} = $value || '';
@@ -156,17 +154,13 @@ L<Business::US::USPS::WebTools>
 
 The WebTools API is documented on the US Postal Service's website:
 
-http://www.usps.com/webtools/htm/Address-Information.htm
+https://www.usps.com/business/web-tools-apis/address-information-api.pdf
 
 =head1 SOURCE AVAILABILITY
 
-This source is part of a SourceForge project which always has the
-latest sources in CVS, as well as all of the previous releases.
+This source is in GitHub:
 
-	http://sourceforge.net/projects/brian-d-foy/
-
-If, for some reason, I disappear from the world, one of the other
-members of the project can shepherd this module appropriately.
+	https://github.com/briandfoy/business-us-usps-webtools
 
 =head1 AUTHOR
 
@@ -174,9 +168,10 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2006-2015, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2006-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
-You may redistribute this under the same terms as Perl itself.
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
 
