@@ -1,3 +1,6 @@
+use v5.10;
+use utf8;
+
 package Business::US::USPS::WebTools::ZipCodeLookup;
 use strict;
 no warnings 'uninitialized';
@@ -7,7 +10,7 @@ use parent qw(Business::US::USPS::WebTools);
 use subs qw();
 use vars qw($VERSION);
 
-$VERSION = '1.12';
+$VERSION = '1.121';
 
 =encoding utf8
 
@@ -78,8 +81,7 @@ details on error information.
 
 =cut
 
-sub lookup_zipcode
-	{
+sub lookup_zipcode {
 	my( $self, %hash ) = @_;
 
 	$self->_make_url( \%hash );
@@ -92,8 +94,7 @@ sub lookup_zipcode
 
 sub _api_name { "ZipCodeLookup" }
 
-sub _make_query_xml
-	{
+sub _make_query_xml {
 	my( $self, $hash ) = @_;
 
 	my $user = $self->userid;
@@ -113,14 +114,12 @@ sub _make_query_xml
 	return $xml;
 	}
 
-sub _parse_response
-	{
+sub _parse_response {
 	my( $self ) = @_;
 	#require 'Hash::AsObject';
 
 	my %hash = ();
-	foreach my $field ( $self->_fields, qw( Zip5 Zip4 ) )
-		{
+	foreach my $field ( $self->_fields, qw( Zip5 Zip4 ) ) {
 		my( $value ) = $self->response =~ m|<$field>(.*?)</$field>|g;
 
 		$hash{$field} = $value || '';
@@ -143,13 +142,9 @@ http://www.usps.com/webtools/htm/Address-Information.htm
 
 =head1 SOURCE AVAILABILITY
 
-This source is part of a SourceForge project which always has the
-latest sources in CVS, as well as all of the previous releases.
+This source is in GitHub:
 
-	http://sourceforge.net/projects/brian-d-foy/
-
-If, for some reason, I disappear from the world, one of the other
-members of the project can shepherd this module appropriately.
+	https://github.com/briandfoy/business-us-usps-webtools
 
 =head1 AUTHOR
 
@@ -157,7 +152,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2006-2015, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2006-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
